@@ -51,7 +51,7 @@ class AboutDialog(gtk.AboutDialog):
         # translation at your discretion.
         self.set_program_name(_("NFO Viewer"))
         self.set_version(nfoview.__version__)
-        self.set_copyright(u"Copyright \xa9 2005-2009 Osmo Salomaa")
+        self.set_copyright(u"Copyright \xa9 2005-2010 Osmo Salomaa")
         self.set_comments(_("Viewer for NFO files"))
         self.set_license(_license)
         self.set_wrap_license(True)
@@ -70,4 +70,4 @@ class AboutDialog(gtk.AboutDialog):
 
     def _on_url_clicked(self, dialog, url):
         """Open website in a web browser."""
-        nfoview.util.browse_url(url)
+        nfoview.util.show_uri(url)
