@@ -20,43 +20,43 @@ import gtk
 import nfoview
 _ = nfoview.i18n._
 
-__all__ = (
-    "CloseDocumentAction",
-    "CopyTextAction",
-    "EditPreferencesAction",
-    "OpenFileAction",
-    "QuitAction",
-    "SelectAllTextAction",
-    "ShowAboutDialogAction",
-    "ShowEditMenuAction",
-    "ShowFileMenuAction",
-    "ShowHelpMenuAction",)
+__all__ = ("CloseDocumentAction",
+           "CopyTextAction",
+           "EditPreferencesAction",
+           "OpenFileAction",
+           "QuitAction",
+           "SelectAllTextAction",
+           "ShowAboutDialogAction",
+           "ShowEditMenuAction",
+           "ShowFileMenuAction",
+           "ShowHelpMenuAction",
+           "WrapLinesAction",
+           )
 
 
 class Action(gtk.Action):
 
     """Base class for UI manager actions.
 
-    Instance variable 'accelerator' defines a string string in the format
-    understood by the gtk.accelerator_parse(), None to use the stock
-    accelerator or leave undefined to use a blank string as a fallback.
+    :ivar accelerator: Accelerator string for :func:`gtk.accelerator_parse`
+
+    Instance variable :attr:`accelerator` defines a string string in the format
+    understood by :func:`gtk.accelerator_parse`, ``None`` to use the stock
+    accelerator or leave undefined to use blank string as a fallback.
     """
 
     accelerator = ""
 
     def __init__(self, name):
-        """Initialize an Action instance."""
-
+        """Initialize an :class:`Action` instance."""
         gtk.Action.__init__(self, name, None, None, None)
 
     def _affirm_doable(self, window):
-        """Raise AffirmationError if action cannot be done."""
-
+        """Raise :exc:`AffirmationError` if action cannot be done."""
         pass
 
     def update_sensitivity(self, window):
         """Update the sensitivity of action."""
-
         try:
             self._affirm_doable(window)
         except nfoview.AffirmationError:
@@ -64,13 +64,19 @@ class Action(gtk.Action):
         return self.set_sensitive(True)
 
 
+class ToggleAction(Action, gtk.ToggleAction):
+
+    """Base class for UI manager toggle actions."""
+
+    pass
+
+
 class CloseDocumentAction(Action):
 
     """Close document."""
 
     def __init__(self):
-        """Initialize a CloseDocumentAction instance."""
-
+        """Initialize a :class:`CloseDocumentAction` instance."""
         Action.__init__(self, "close_document")
         self.props.label = _("_Close")
         self.props.stock_id = gtk.STOCK_CLOSE
@@ -83,8 +89,7 @@ class CopyTextAction(Action):
     """Copy the selected text to the clipboard."""
 
     def __init__(self):
-        """Initialize a CopyTextAction instance."""
-
+        """Initialize a :class:`CopyTextAction` instance."""
         Action.__init__(self, "copy_text")
         self.props.is_important = True
         self.props.label = _("_Copy")
@@ -94,8 +99,7 @@ class CopyTextAction(Action):
         self.accelerator = "<Control>C"
 
     def _affirm_doable(self, window):
-        """Raise AffirmationError if action cannot be done."""
-
+        """Raise :exc:`AffirmationError` if action cannot be done."""
         nfoview.util.affirm(window.view is not None)
         nfoview.util.affirm(window.view.props.sensitive)
         text_buffer = window.view.get_buffer()
@@ -107,8 +111,7 @@ class EditPreferencesAction(Action):
     """Edit NFO Viewer preferences."""
 
     def __init__(self):
-        """Initialize an EditPreferencesAction instance."""
-
+        """Initialize an :class:`EditPreferencesAction` instance."""
         Action.__init__(self, "edit_preferences")
         self.props.label = _("_Preferences")
         self.props.stock_id = gtk.STOCK_PREFERENCES
@@ -120,8 +123,7 @@ class OpenFileAction(Action):
     """Open file."""
 
     def __init__(self):
-        """Initialize an OpenFileAction instance."""
-
+        """Initialize an :class:`OpenFileAction` instance."""
         Action.__init__(self, "open_file")
         self.props.is_important = True
         self.props.label = _("_Open...")
@@ -136,8 +138,7 @@ class QuitAction(Action):
     """Close all documents and quit NFO Viewer."""
 
     def __init__(self):
-        """Initialize a QuitAction instance."""
-
+        """Initialize a :class:`QuitAction` instance."""
         Action.__init__(self, "quit")
         self.props.label = _("_Quit")
         self.props.stock_id = gtk.STOCK_QUIT
@@ -145,47 +146,42 @@ class QuitAction(Action):
         self.accelerator = "<Control>Q"
 
 
-class ShowAboutDialogAction(Action):
-
-    """Show information about NFO Viewer."""
-
-    def __init__(self):
-        """Initialize a ShowAboutDialogAction instance."""
-
-        Action.__init__(self, "show_about_dialog")
-        self.props.label = _("_About")
-        self.props.stock_id = gtk.STOCK_ABOUT
-        self.props.tooltip = _("Show information about NFO Viewer")
-
-
 class SelectAllTextAction(Action):
 
     """Select all text in the document."""
 
     def __init__(self):
-        """Initialize a SelectAllTextAction instance."""
-
+        """Initialize a :class:`SelectAllTextAction` instance."""
         Action.__init__(self, "select_all_text")
         self.props.label = _("_Select All")
-        if hasattr(gtk, "STOCK_SELECT_ALL"):
-            self.props.stock_id = gtk.STOCK_SELECT_ALL
+        self.props.stock_id = gtk.STOCK_SELECT_ALL
         self.props.tooltip = _("Select all text in the document")
         self.accelerator = "<Control>A"
 
     def _affirm_doable(self, window):
-        """Raise AffirmationError if action cannot be done."""
-
+        """Raise :exc:`AffirmationError` if action cannot be done."""
         nfoview.util.affirm(window.view is not None)
         nfoview.util.affirm(window.view.props.sensitive)
 
 
+class ShowAboutDialogAction(Action):
+
+    """Show information about NFO Viewer."""
+
+    def __init__(self):
+        """Initialize a :class:`ShowAboutDialogAction` instance."""
+        Action.__init__(self, "show_about_dialog")
+        self.props.label = _("_About")
+        self.props.stock_id = gtk.STOCK_ABOUT
+        self.props.tooltip = _("Show information about NFO Viewer")
+
+
 class ShowEditMenuAction(Action):
 
     """Show the edit menu."""
 
     def __init__(self):
-        """Initialize a ShowEditMenuAction instance."""
-
+        """Initialize a :class:`ShowEditMenuAction` instance."""
         Action.__init__(self, "show_edit_menu")
         self.props.label = _("_Edit")
 
@@ -195,8 +191,7 @@ class ShowFileMenuAction(Action):
     """Show the file menu."""
 
     def __init__(self):
-        """Initialize a ShowFileMenuAction instance."""
-
+        """Initialize a :class:`ShowFileMenuAction` instance."""
         Action.__init__(self, "show_file_menu")
         self.props.label = _("_File")
 
@@ -206,7 +201,24 @@ class ShowHelpMenuAction(Action):
     """Show the help menu."""
 
     def __init__(self):
-        """Initialize a ShowHelpMenuAction instance."""
-
+        """Initialize a :class:`ShowHelpMenuAction` instance."""
         Action.__init__(self, "show_help_menu")
         self.props.label = _("_Help")
+
+
+class WrapLinesAction(ToggleAction):
+
+    """Break long lines at word borders."""
+
+    def __init__(self):
+        """Initialize a :class:`WrapLinesAction` instance."""
+        ToggleAction.__init__(self, "wrap_lines")
+        self.props.active = False
+        self.props.label = _("_Wrap Lines")
+        self.props.tooltip = _("Break long lines at word borders")
+        self.accelerator = "<Control>R"
+
+    def _affirm_doable(self, window):
+        """Raise :exc:`AffirmationError` if action cannot be done."""
+        nfoview.util.affirm(window.view is not None)
+        nfoview.util.affirm(window.view.props.sensitive)
