@@ -14,14 +14,42 @@
 # You should have received a copy of the GNU General Public License along with
 # NFO Viewer. If not, see <http://www.gnu.org/licenses/>.
 
-"""Classes and functions for defining and accessing color schemes."""
+"""Classes for color scheme definitions."""
 
 import gtk
 import nfoview
 _ = nfoview.i18n._
 
+__all__ = ("BlackOnWhiteScheme",
+           "CustomScheme",
+           "DarkGreyOnLightGrayScheme",
+           "DefaultScheme",
+           "GreyOnBlackScheme",
+           "LightGreyOnDarkGrayScheme",
+           "WhiteOnBlackScheme",)
 
-class BlackOnWhiteScheme(object):
+
+class ColorScheme(object):
+
+    """Baseclass for color scheme definitions.
+
+    :cvar name: Name used to identify and save color scheme
+    :cvar label: User-visible localized name for color scheme
+    :cvar foreground: Foreground color as a :class:`gtk.gdk.Color`
+    :cvar background: Background color as a :class:`gtk.gdk.Color`
+    :cvar link: Link color as a :class:`gtk.gdk.Color`
+    :cvar visited_link: Visited link color as a :class:`gtk.gdk.Color`
+    """
+
+    name = "custom"
+    label = _("Custom")
+    foreground = gtk.gdk.color_parse(nfoview.conf.foreground_color)
+    background = gtk.gdk.color_parse(nfoview.conf.background_color)
+    link = gtk.gdk.color_parse(nfoview.conf.link_color)
+    visited_link = gtk.gdk.color_parse(nfoview.conf.visited_link_color)
+
+
+class BlackOnWhiteScheme(ColorScheme):
 
     """Color scheme with black text on white background."""
 
@@ -33,7 +61,7 @@ class BlackOnWhiteScheme(object):
     visited_link = gtk.gdk.color_parse("#ff00ff")
 
 
-class CustomScheme(object):
+class CustomScheme(ColorScheme):
 
     """Color scheme with custom, user-chosen colors."""
 
@@ -45,7 +73,7 @@ class CustomScheme(object):
     visited_link = gtk.gdk.color_parse(nfoview.conf.visited_link_color)
 
 
-class DarkGreyOnLightGrayScheme(object):
+class DarkGreyOnLightGrayScheme(ColorScheme):
 
     """Color scheme with dark grey text on light grey background."""
 
@@ -53,11 +81,11 @@ class DarkGreyOnLightGrayScheme(object):
     label = _("Dark grey on light grey")
     foreground = gtk.gdk.color_parse("#666666")
     background = gtk.gdk.color_parse("#f2f2f2")
-    link = gtk.gdk.color_parse("#5455ff")
-    visited_link = gtk.gdk.color_parse("#ff54ff")
+    link = gtk.gdk.color_parse("#5555ff")
+    visited_link = gtk.gdk.color_parse("#ff55ff")
 
 
-class DefaultScheme(object):
+class DefaultScheme(ColorScheme):
 
     """Color scheme with default fore- and background colors."""
 
@@ -66,11 +94,11 @@ class DefaultScheme(object):
     _style = gtk.TextView().rc_get_style()
     foreground = _style.text[gtk.STATE_NORMAL]
     background = _style.base[gtk.STATE_NORMAL]
-    link = gtk.gdk.color_parse("#5455ff")
-    visited_link = gtk.gdk.color_parse("#ff54ff")
+    link = gtk.gdk.color_parse("#5555ff")
+    visited_link = gtk.gdk.color_parse("#ff55ff")
 
 
-class GreyOnBlackScheme(object):
+class GreyOnBlackScheme(ColorScheme):
 
     """Color scheme with grey text on black background."""
 
@@ -78,11 +106,11 @@ class GreyOnBlackScheme(object):
     label = _("Grey on black")
     foreground = gtk.gdk.color_parse("#aaaaaa")
     background = gtk.gdk.color_parse("#000000")
-    link = gtk.gdk.color_parse("#abacff")
-    visited_link = gtk.gdk.color_parse("#ffabff")
+    link = gtk.gdk.color_parse("#aaaaff")
+    visited_link = gtk.gdk.color_parse("#ffaaff")
 
 
-class LightGreyOnDarkGrayScheme(object):
+class LightGreyOnDarkGrayScheme(ColorScheme):
 
     """Color scheme with light grey text on dark grey background."""
 
@@ -90,11 +118,11 @@ class LightGreyOnDarkGrayScheme(object):
     label = _("Light grey on dark grey")
     foreground = gtk.gdk.color_parse("#f2f2f2")
     background = gtk.gdk.color_parse("#666666")
-    link = gtk.gdk.color_parse("#abacff")
-    visited_link = gtk.gdk.color_parse("#ffabff")
+    link = gtk.gdk.color_parse("#aaaaff")
+    visited_link = gtk.gdk.color_parse("#ffaaff")
 
 
-class WhiteOnBlackScheme(object):
+class WhiteOnBlackScheme(ColorScheme):
 
     """Color scheme with white text on black background."""
 
@@ -102,31 +130,5 @@ class WhiteOnBlackScheme(object):
     label = _("White on black")
     foreground = gtk.gdk.color_parse("#ffffff")
     background = gtk.gdk.color_parse("#000000")
-    link = gtk.gdk.color_parse("#abacff")
-    visited_link = gtk.gdk.color_parse("#ffabff")
-
-
-def _get_color_scheme_classes():
-    """Get a list of all color scheme classes."""
-
-    return [eval(x) for x in globals() if x.endswith("Scheme")]
-
-def get_color_scheme(name):
-    """Get the color scheme class with given name.
-
-    Raise ValueError if name not found among color schemes.
-    """
-    schemes = _get_color_scheme_classes()
-    names = [x.name for x in schemes]
-    return schemes[names.index(name)]
-
-def get_color_schemes():
-    """Get a list of all color scheme classes in proper order."""
-
-    schemes = _get_color_scheme_classes()
-    schemes.remove(DefaultScheme)
-    schemes.remove(CustomScheme)
-    schemes.sort(lambda x, y: cmp(x.label, y.label))
-    schemes.insert(0, DefaultScheme)
-    schemes.append(CustomScheme)
-    return schemes
+    link = gtk.gdk.color_parse("#aaaaff")
+    visited_link = gtk.gdk.color_parse("#ffaaff")
